[Groonga-commit] groonga/gcs [master] Remove "debug..." message

Back to archive index

null+****@clear***** null+****@clear*****
2012年 7月 12日 (木) 16:29:19 JST


SHIMODA Hiroshi	2012-07-12 16:29:19 +0900 (Thu, 12 Jul 2012)

  New Revision: 2e989613f147146a4315858164d992e7ef175d30
  https://github.com/groonga/gcs/commit/2e989613f147146a4315858164d992e7ef175d30

  Log:
    Remove "debug..." message

  Modified files:
    lib/api/2011-02-01/batch.js
    lib/database/domain.js

  Modified: lib/api/2011-02-01/batch.js (+2 -2)
===================================================================
--- lib/api/2011-02-01/batch.js    2012-07-12 16:23:21 +0900 (23a375d)
+++ lib/api/2011-02-01/batch.js    2012-07-12 16:29:19 +0900 (679c9be)
@@ -38,7 +38,7 @@ function handleInvalidContentLength(request, response) {
   return true;
 }
 
-exports.createHandler = function(database) {
+exports.createHandler = function(context) {
   return function(request, response) {
     if (handleInvalidContentType(request, response)) return;
     if (handleInvalidContentLength(request, response)) return;
@@ -46,7 +46,7 @@ exports.createHandler = function(database) {
     var batches = request.body;
     var domain = new Domain(request);
     var processor = new BatchProcessor({
-          database: database,
+          context: context,
           domain: domain
         });
 

  Modified: lib/database/domain.js (+3 -3)
===================================================================
--- lib/database/domain.js    2012-07-12 16:23:21 +0900 (5091852)
+++ lib/database/domain.js    2012-07-12 16:29:19 +0900 (1482a7d)
@@ -78,15 +78,15 @@ Domain.prototype = {
     return this.indexFields[field] ||
            (this.indexFields[field] = new IndexField(field, this));
   },
-  getIndexFieldsSync: function(database) {
-    var columns = database.ordinalColumnsSync(this.tableName);
+  getIndexFieldsSync: function(context) {
+    var columns = context.ordinalColumnsSync(this.tableName);
     var fields = columns.map(this.columnToIndexField, this);
     return fields;
   },
   columnToIndexField: function(column) {
     // XXX The "name" must be the field name given by the user,
     // not normalized. Because there is no such information in the
     // database and currently the column name is luckly equals to the
     // given field name, we can use the column name.
     var name = column.name;
     var field = this.getIndexField(name);
-------------- next part --------------
@@ -78,15 +78,15 @@ Domain.prototype = {
     // XXX The "name" must be the field name given by the user,
     // not normalized. Because there is no such information in the
-    // database and currently the column name is luckly equals to the
+    // context and currently the column name is luckly equals to the
     // given field name, we can use the column name.
     var name = column.name;
HTML$B$NE:IU%U%!%$%k$rJ]4I$7$^$7$?(B...
下载 



Groonga-commit メーリングリストの案内
Back to archive index